
/*
           sunseeker.h - Definitions for the SunSeeker solar array tracker
           
           Created by Graig Pearen 2012 03 05 for the
           DesignSpark Max32 Arduino design contest
*/

//  PIN DEFINITIONS

  #define pinEastSensor    54         // east light sensor
  #define pinWestSensor    55         // west light sensor
  #define pinUpSensor      56         // up light sensor
  #define pinDownSensor    57         // down light sensor
  #define pinSunSensor     58         // sun light sensor
  #define pinSnowSensor    59         // snow (reflected light) sensor
  #define pinAzFeedback    62         // azimuth motor current
  #define pinElFeedback    63         // elevation motor current

  #define pinSDA1          20         // EEPROM I2C clock
  #define pinSCL1          21         // EEPROM I2C data in/out
  #define pinPvTemp        31         // PV temperature data I/O
  #define pinAirTemp       32         // ambient temperature data I/O

  #define pinSCL2          12         // SCL2 I2C clock (sensoe module)
  #define pinSDA2          13         // SDA2 I2C data in/out (sensor module)
  #define pinVDD           82         // 3.3v power to the sensor module

  #define pinHBridgeFault  33         // H-bridhe fault sense input
  #define pinElEnable      34         // H-bridge elevation enable
  #define pinAzEnable      35         // H-bridge azimuth enable
  #define pinHBridgeIn2    36         // H-bridge direction control input-2 (port E1)
  #define pinHBridgeIn1    37         // H-bridge direction control input-1 (port E0)

  #define pinPsDis         30         // 48-volt power supply disable
  #define pinAP            70         // azimuth pulse input
  #define pinEP            71         // elevation pulse input
  #define pinAls           72         // optional azimuth limit switch input
  #define pinEls           73         // optional elevation limit switch input
  #define pinVib           77         // vibrator motor output
 
/* ETHERNET    (Defined in the ethernet header file)
   40  RXERR
   41  RXD1
   42  RXD0
   43  CRSDV
   45  TXD1
   46  TXD0
   47  TXEN
   48  MDIO
   49  MDC
   53  REFCLK
*/

//------------------------------------ MISCELLANEOUS CONSTANTS -----------------------------------

int     IMin      =  500;           // minimum motor current in ma, less than this is a fault
int     IMax      = 3000;           // maximum motor current in ma, more indicates a mechanical fault

/*------------------------------------ STATUS CODES / MESSAGE NUMBERS -----------------------------------
 
   Each mode, condition, or status is assigned a different number between 0 and 255.
   This allows any one item to be interpreted in more than one way.
   For example, DAWN is both a status and the number of a message that can be printed.
   Likewise, PARKED is both an operating mode and a printable message.
*/

// ------ ERROR CODES ------

  #define OK         0              // no hardware fault
  #define AZW        1              // azimuth fail moving west, no pulse
  #define AZE        2              // azimuth fail moving east, no pulse
  #define ELU        3              // elevation fail moving up, no pulse
  #define ELD        4              // elevation fail moving down, no pulse
  #define AIL        5              // azimuth low current
  #define AIH        6              // azimuth high current
  #define EIL        7              // elevation current low
  #define EIH        8              // elevation current high


// ------ SKY CONDITION ------

  #define DARK       10             // sky conditions
  #define DAWN       11             // sunrise
  #define DUSK       12             // sunset
  #define CLOUDY     13  
  #define HAZY       14  
  #define SUNNY      15  

// ------ TRACKING MODE ------      // if "manual" is set, tracking is stopped

  #define TRACKING   16             // array is tracking the sun
  #define PARKED     17             // array is parked for the night
  #define STOWED     18             // array is stowed for protection from high wind
  #define AUTO       19             // automatic mode


// ------ WARNINGS ------

  #define AZNEG      20             // azimuth pulse count went negative (new maximum east position)
  #define ELNEG      21             // elevation pulse went negative (new vertical position)
  #define BUG1       22             // invalid direction (must be U,D,E,W)
  #define BUG2       23             // invalid sky condition
  #define BUG3       24             // invalid ID of a suspended program
  #define BUG4       25             // invalid mode
  #define BUG5       26             // 
  #define BUG6       27             // 
  #define BUG6       28             // 
  #define BUG8       29             // 
  
//------------------------------------ THRESHOLDS -----------------------------------

  #define dawn      3               // less than this is dark
  #define cloud     5               // less than this is dawn
  #define haze     10               // less than this is cloudy
  #define sun      20               // less than this is hazy, more is sunny
  #define AZPARK    2               // default azimuth count (where to stop when parking)
  #define ELPARK    2               // default elevation count (where to stop when parking the array)
  #define ELSTOW  255               // default elevation count f(where to stop when stowing the array)
 




